@@ -113,6 +113,7 @@ func startPagingWithTabSize(t *testing.T, tabSize int, reader *reader.ReaderImpl
 	pager := NewPager(reader)
 	pager.TabSize = tabSize
 	pager.ShowLineNumbers = false
+	pager.showLineNumbers = false
 
 	// Tell our Pager to quit immediately
 	pager.Quit()
@@ -136,6 +137,7 @@ func startPagingWithTerminalFg(t *testing.T, reader *reader.ReaderImpl, withTerm
 	screen := twin.NewFakeScreen(20, 10)
 	pager := NewPager(reader)
 	pager.ShowLineNumbers = false
+	pager.showLineNumbers = false
 	pager.WithTerminalFg = withTerminalFg
 
 	// Tell our Pager to quit immediately
@@ -422,6 +424,7 @@ func TestScrollToBottomWrapNextToLastLine(t *testing.T) {
 	pager := NewPager(reader)
 	pager.WrapLongLines = true
 	pager.ShowLineNumbers = false
+	pager.showLineNumbers = false
 	pager.screen = screen
 
 	assert.NilError(t, pager.readers[pager.currentReader].Wait())
@@ -457,6 +460,7 @@ func TestScrollToEndLongInput(t *testing.T) {
 	reader := reader.NewFromTextForTesting("test", strings.Repeat(".\n", lineCount-1)+"X")
 	pager := NewPager(reader)
 	pager.ShowLineNumbers = true
+	pager.showLineNumbers = true
 
 	// Tell our Pager to quit immediately
 	pager.Quit()
@@ -604,6 +608,7 @@ func TestPageSamples(t *testing.T) {
 			pager := NewPager(myReader)
 			pager.WrapLongLines = false
 			pager.ShowLineNumbers = false
+			pager.showLineNumbers = false
 
 			// Heigh 3 = two lines of contents + one footer
 			screen := twin.NewFakeScreen(10, 3)
@@ -671,6 +676,7 @@ func TestClearToEndOfLine_ClearFromNotStart(t *testing.T) {
 func TestClearToEndOfLine_ClearFromStartScrolledRight(t *testing.T) {
 	pager := NewPager(reader.NewFromTextForTesting("TestClearToEol", blueBackgroundClearToEol0))
 	pager.ShowLineNumbers = false
+	pager.showLineNumbers = false
 
 	// Tell our Pager to quit immediately
 	pager.Quit()
