@@ -7,13 +7,14 @@ import (
 	"github.com/alecthomas/chroma/v2"
 	"github.com/alecthomas/chroma/v2/formatters"
 	"github.com/alecthomas/chroma/v2/styles"
-	"github.com/walles/moor/twin"
+	"github.com/walles/moor/v2/twin"
 	"gotest.tools/v3/assert"
 )
 
 func TestTwinStyleFromChroma(t *testing.T) {
 	// Test that getting exact GenericHeading from base16-snazzy works
 	style := twinStyleFromChroma(
+		nil,
 		styles.Registry["base16-snazzy"],
 		&formatters.TTY16m,
 		chroma.GenericHeading,
@@ -34,3 +35,11 @@ func TestSetStyle(t *testing.T) {
 
 	assert.Equal(t, style, twin.StyleDefault.WithAttr(twin.AttrBold).WithForeground(twin.NewColor16(1)))
 }
+
+// Regression test for https://github.com/walles/moor/issues/339
+//
+// We used to crash doing this.
+func TestConfigureHighlighting_No24BitColors(t *testing.T) {
+	searchHitStyle = twin.StyleDefault.WithForeground(twin.NewColor16(3))
+	configureHighlighting(nil)
+}
